@@ -3,7 +3,6 @@ require 5.005;
 use strict;
 use warnings;
 use Carp 'croak';
-use Time::HiRes ();
 
 require Exporter;
 require DynaLoader;
@@ -11,7 +10,7 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.37_04';
+$VERSION = '0.37_05';
 
 %EXPORT_TAGS = (
     'all' => [qw(
@@ -143,7 +142,7 @@ All generated UUIDs are either version 1, 3, 4, 5, 6, or version 7. And
 all are variant 1, meaning compliant with the OSF DCE standard as
 described in RFC4122.
 
-Versions 6 and 7 are not standardized. They are presented here as
+Versions 6 and 7 are not yet standardized. They are presented here as
 proposed in RFC4122bis, version 14, and may change in the future.
 RFC4122bis is noted to replace RFC4122, if approved.
 
@@ -376,30 +375,6 @@ Known versions:
     v7  reverse unix date/time and random
     v8  custom
 
-=head1 MAINTAINING STATE
-
-Internal state is optionally maintained for timestamped UUIDs (versions
-1, 6, and 7) via a file designated by the B<:persist> export tag. See
-B<EXPORTS> for details.
-
-The file records various internal states at the time the last UUID is
-generated, preventing future instances from overlapping the prior UUID
-sequence. This allows the sequence to absolutely survive reboots and,
-more importantly, backwards resetting of system time.
-
-If B<:persist> is not used, time resets will still be detected while the
-module is loaded and handled by incrementing the UUID clock_seq field.
-The clock_seq field is randomly initialized in this case anyway, so the
-chance of overlap is low but still exists since clock_seq is only 14
-bits wide. Using a random MAC will help (see B<:mac> in B<EXPORTS>),
-adding an additional 48 bits of randomness.
-
-B<NOTE:> Using B<:persist> incurs a serious performance penalty, in
-excess of 95% on tested platforms. You can run C<make compare> in the
-distribution directory to see how this might affect your application,
-but unless you need many thousands of UUIDs/sec it's probably a
-non-issue.
-
 =head1 RANDOM NUMBERS
 
 Versions 4 and 7 UUIDs are partially filled with random numbers, as well
@@ -410,7 +385,7 @@ I</dev/random> device, or similar interface. On some platforms it called
 B<getrandom()> and on others it read directly from I</dev/urandom>. And
 of course, Win32 did something completely different.
 
-Starting in 0.33, UUID generates random numbers itself using the
+Starting in version 0.33, UUID generates random numbers itself using the
 ChaCha20 algorithm which is considered crypto-strength in most circles.
 This is the same algo used as the basis for many modern kernel RNGs,
 albeit without the same entropy gathering ability.
@@ -423,6 +398,36 @@ can't predict the future.
 
 Well, that's the theory anyway.
 
+Starting in version 0.38, the whole mix is initially seeded from the
+best platform-specific source available which could be one or more of:
+
+    arc4random()
+    BCryptGenRandom()
+    CryptGenRandom()
+    getentropy()
+    getrandom()
+    /dev/urandom
+    /dev/random
+
+=head1 TIME
+
+Time-based UUIDs are formed with time-of-day information gathered from
+I<Time::HiRes>. This provides a portable timestamp with 1us resolution
+facilitating generation rates up to 1M UUIDs/sec without further action.
+
+If UUIDs are required faster than 1us (i.e. > 1M UUIDs/sec), an internal
+counter simulates 100ns intervals, which is the UUID resolution limit.
+Each UUID within the same 1us tick will thus appear to be at successive
+100ns intervals, which probably isn't true.
+
+Should the internal counter exceed 9 within the same 1us period, it is
+reset to 0 and the UUID sequence field is incremented, thus guaranteeing
+uniqueness even though the time sequence will repeat.
+
+This scheme raises the limit of time-based uniqueness to over 16G
+UUIDs/sec, which is well beyond the best benchmarks seen to date.
+(~14M/sec for v6 binary UUIDs on commodity hardware.)
+
 =head1 NAMESPACES
 
 Versions 3 and 5 generate UUIDs within namespaces. What this really
@@ -458,6 +463,30 @@ when merging datasets.
 You also don't need to publish your base and namespace UUIDs. Anyone
 using the same logic can generate the same question and answer UUIDs.
 
+=head1 MAINTAINING STATE
+
+Internal state is optionally maintained for timestamped UUIDs (versions
+1, 6, and 7) via a file designated by the B<:persist> export tag. See
+B<EXPORTS> for details.
+
+The file records various internal states at the time the last UUID is
+generated, preventing future instances from overlapping the prior UUID
+sequence. This allows the sequence to absolutely survive reboots and,
+more importantly, backwards resetting of system time.
+
+If B<:persist> is not used, time resets will still be detected while the
+module is loaded and handled by incrementing the UUID clock_seq field.
+The clock_seq field is randomly initialized in this case anyway, so the
+chance of overlap is low but still exists since clock_seq is only 14
+bits wide. Using a random MAC will help (see B<:mac> in B<EXPORTS>),
+adding an additional 48 bits of randomness.
+
+B<NOTE:> Using B<:persist> incurs a serious performance penalty, in
+excess of 95% on tested platforms. You can run C<make compare> in the
+distribution directory to see how this might affect your application,
+but unless you need many thousands of UUIDs/sec it's probably a
+non-issue.
+
 =head1 EXPORTS
 
 None by default. All functions may be imported in the usual manner,
