@@ -38,8 +38,10 @@ sub generate_conf {
         # sets $WIN32. do this first.
         try_win32_native ($check, \$longest, $defines);
 
+        # NOTE: if you enable HAVE_WINDOWS_H then networking will fail,
+        #       at least on Windows 11.
         try_headers($check, \$longest, $defines, qw(
-            HAVE_WINDOWS_H       Windows.h
+            -HAVE_WINDOWS_H       Windows.h
             HAVE_WINSOCK2_H      winsock2.h
             HAVE_IPHLPAPI_H      iphlpapi.h
             HAVE_BCRYPT_H        bcrypt.h
@@ -65,10 +67,10 @@ sub generate_conf {
             HAVE_SYS_SOCKET_H    sys/socket.h
             HAVE_SYS_SOCKIO_H    sys/sockio.h
             HAVE_SYS_STAT_H      sys/stat.h
-            HAVE_SYS_TIME_H      sys/time.h
+            -HAVE_SYS_TIME_H      sys/time.h
             HAVE_SYS_TYPES_H     sys/types.h
             HAVE_SYS_WAIT_H      sys/wait.h
-            HAVE_TIME_H          time.h
+            -HAVE_TIME_H          time.h
             HAVE_UNISTD_H        unistd.h
             HAVE_WINCRYPT_H      wincrypt.h
         ));
@@ -78,6 +80,7 @@ sub generate_conf {
         try_CryptGenRandom  ($check, \$longest, $defines);
         try_getentropy      ($check, \$longest, $defines);
         try_getrandom       ($check, \$longest, $defines);
+        #try_gettimeofday    ($check, \$longest, $defines);
         try_lstat           ($check, \$longest, $defines);
         try_sa_len          ($check, \$longest, $defines);
         try_symlink         ($check, \$longest, $defines);
@@ -299,6 +302,35 @@ sub try_getrandom {
     unlink $conf;
 }
 
+sub try_gettimeofday {
+    my ($check, $long, $defs) = @_;
+    my $msg = 'Checking gettimeofday()';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+    my $conf = gen_confh($defs);
+    if ( check_lib(
+        header   => $conf,
+        lib      => 'c', # always do at least this
+        ccflags  => '-I.',
+        debug    => 0,
+        function => '
+            struct timeval tv;
+            int r = gettimeofday(&tv, 0);
+            return 0;
+            (void)r;
+        ',
+    )) {
+        push @$defs, '#define HAVE_GETTIMEOFDAY 1';
+        print $msg, ' ..', '.'x$more, ' found';
+    }
+    else {
+        push @$defs, '#undef HAVE_GETTIMEOFDAY';
+        print $msg, ' ..', '.'x$more, ' missing';
+    }
+    unlink $conf;
+}
+
 sub try_lstat {
     my ($check, $long, $defs) = @_;
     my $msg = 'Checking lstat()';
