@@ -14,17 +14,19 @@ void (*myU2time)(pTHX_ UV ret[2]);
 /* called at boot */
 void uu_gettime_init(pUCXT) {
   SV **svp;
-
+  require_pv("Time/HiRes.pm");
   svp = hv_fetchs(PL_modglobal, "Time::U2time", 0);
   if (!svp)         croak("Time::HiRes is required");
   if (!SvIOK(*svp)) croak("Time::U2time isn't a function pointer");
   myU2time = INT2PTR(void(*)(pTHX_ UV ret[2]), SvIV(*svp));
-  if (0) { /* test */
+/*
+  if (0) {
     UV  xx[2];
     (*myU2time)(aTHX_ xx);
     printf("The current seconds are: %" UVuf ".%06" UVuf "\n", xx[0], xx[1]);
     exit(0);
   }
+*/
 }
 
 U64 gt_100ns64(pUCXT) {
