@@ -4,6 +4,7 @@ extern "C" {
 
 #include "ulib/splitmix.h"
 #include "ulib/gettime.h"
+#include "ulib/sysrand.h"
 
 #ifdef __cplusplus
 }
@@ -14,9 +15,6 @@ extern "C" {
 */
 
 void sm_srand(pUCXT, Pid_t pid) {
-  unsigned int  n;
-  UV            ptod[2];
-
   /*
    * The idea is to just have a unique value here,
    * so system time and process id should be enough.
@@ -27,10 +25,17 @@ void sm_srand(pUCXT, Pid_t pid) {
    *
    * So, lets initially seed with TOD, mix, add the PID,
    * then mix again.
+   *
+   * And finally, since we've already abandoned the goal
+   * of uniqueness, we'll add some system randomness and
+   * mix again.
   */
+  unsigned int  n;
+  UV            ptod[2];
+  U64           sysrand;
 
   /* gettimeofday(&tv, 0); */
-  (*UCXT.myU2time)(aTHX_ (UV*)&ptod);
+  (*myU2time)(aTHX_ ptod);
   UCXT.sm_x = (U64)ptod[0] * 1000000
     + (U64)ptod[1];
 
@@ -45,6 +50,14 @@ void sm_srand(pUCXT, Pid_t pid) {
   n = 16 + ((ptod[0] ^ ptod[1]) & 0x0f);
   while (n-- > 0)
     (void)sm_rand(aUCXT);
+
+  sr_rand_bytes(&sysrand, 8);
+  UCXT.sm_x ^= sysrand;
+
+  /* stir 16 - 31 times, rand-based */
+  n = 16 + (sysrand & 0x0f);
+  while (n-- > 0)
+    (void)sm_rand(aUCXT);
 }
 
 U64 sm_rand(pUCXT) {
